@@ -293,7 +293,7 @@ class ClBuilderUpdateAction(Action):
                  'tasks': [
                      {'name': 'update_depclean',
                       'message': __("Calculating dependencies"),
-                      'method': 'Builder.depclean(cl_builder_clean_bdeps_set)',
+                      'method': 'Builder.depclean()',
                       },
                  ]
                  },
