@@ -193,6 +193,7 @@ class Wsdl(WsdlBase):
                         'update.cl_update_skip_rb_set',
                         'update.cl_update_onedepth_set',
                         'update.cl_update_cleanpkg_set',
+                        'builder.cl_builder_check_automagic_set',
                         'cl_builder_branch_data',
                         'cl_templates_locate',
                         'cl_verbose_set',
@@ -214,6 +215,7 @@ class Wsdl(WsdlBase):
                         'update.cl_update_skip_rb_set',
                         'update.cl_update_onedepth_set',
                         'update.cl_update_cleanpkg_set',
+                        'builder.cl_builder_check_automagic_set',
                         'cl_builder_branch_data',
                         'cl_templates_locate',
                         'cl_verbose_set',
@@ -236,6 +238,7 @@ class Wsdl(WsdlBase):
                         'update.cl_update_skip_rb_set',
                         'update.cl_update_onedepth_set',
                         'update.cl_update_cleanpkg_set',
+                        'builder.cl_builder_check_automagic_set',
                         'cl_builder_brief_branch_data',
                     ),
                     next_label=_("Next"))],
@@ -371,6 +374,7 @@ class Wsdl(WsdlBase):
                                            'cl_builder_isohybrid_set',
                                            'cl_builder_keep_tree_set',
                                            'cl_builder_prelink_set',
+                                           'cl_builder_update_themes_set',
                                            'cl_builder_prepare_free_size',
                                            'cl_builder_image_free_size'
                                            ),
@@ -381,6 +385,7 @@ class Wsdl(WsdlBase):
                                           'cl_builder_image_filename',
                                           'cl_builder_videodrv_set',
                                           'cl_builder_compress',
+                                          'cl_builder_update_themes_set',
                                           'cl_builder_keep_tree_set',
                                           'cl_builder_isohybrid_set',
                                           'cl_builder_prelink_set',
@@ -394,6 +399,7 @@ class Wsdl(WsdlBase):
                                         'cl_builder_prelink_set',
                                         'cl_builder_compress',
                                         'cl_builder_binhost_stable_set',
+                                        'cl_builder_update_themes_set',
                                         'cl_templates_locate',
                                         'cl_verbose_set',
                                         'cl_dispatch_conf'),
